@@ -61,6 +61,7 @@
 #include "dock.h"
 #include "workspace.h"
 #include "properties.h"
+#include "rootmenu.h"
 
 #define MAX_SHORTCUT_LENGTH 32
 
@@ -998,6 +999,9 @@ void wDefaultsCheckDomains(void* arg)
 				}
 				WDRootMenu->dictionary = dict;
 				wDefaultsMergeGlobalMenus(WDRootMenu);
+				scr = wScreenWithNumber(0);
+				configureMenu(scr, dict, True);
+				rebind_key_grabs(scr);
 			}
 		} else {
 			wwarning(_("could not load domain %s from user defaults database"), "WMRootMenu");
